# DBND Postgres

## The plugin
`dbnd-postgres` create histograms for postgres tables.
The plugin supports Redshift.

### What does it do?
It uses internal/system postgres tables to create the histograms. It doesn't query user tables at all.

### Installation
```bash
pip install dbnd-postgres
```
